package com.alterdekim.game.component.game.inventory;

import com.alterdekim.game.xml.LocalDateTimeSerializer;
import com.alterdekim.game.xml.NumericBooleanSerializer;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import java.time.LocalDateTime;

@Getter
@AllArgsConstructor
@NoArgsConstructor
public class InventoryItem {

    @Setter
    @JacksonXmlProperty(isAttribute = true, localName = "ID")
    private Long id;

    @JacksonXmlProperty(isAttribute = true, localName = "TextResourceID")
    private Long textResourceId;

    @JacksonXmlProperty(isAttribute = true, localName = "BodyPartId")
    private Long bodyPartId;

    @JacksonXmlProperty(isAttribute = true, localName = "MediaResourceID")
    private Integer mediaResourceId;

    @JacksonXmlProperty(isAttribute = true, localName = "IsUsed")
    @JsonSerialize(using = NumericBooleanSerializer.class)
    @Setter
    private Boolean isUsed;

    @JacksonXmlProperty(isAttribute = true, localName = "IsColorable")
    @JsonSerialize(using = NumericBooleanSerializer.class)
    private Boolean isColorable;

    @JacksonXmlProperty(isAttribute = true, localName = "Color")
    private Integer color;

    @JacksonXmlProperty(isAttribute = true, localName = "IsLimited")
    @JsonSerialize(using = NumericBooleanSerializer.class)
    private Boolean isLimited;

    @JacksonXmlProperty(isAttribute = true, localName = "Date")
    @JsonSerialize(using = LocalDateTimeSerializer.class)
    private LocalDateTime date;

    @JacksonXmlProperty(isAttribute = true, localName = "Pollution")
    private Integer pollution;

    @JacksonXmlProperty(isAttribute = true, localName = "IsBodyPart")
    @JsonSerialize(using = NumericBooleanSerializer.class)
    private Boolean isBodyPart;

    @Setter
    @JacksonXmlProperty(isAttribute = true, localName = "PhoneId")
    private Long phoneId;

    public static InventoryItem newBackground(Long id, Boolean isUsed) {
        InventoryItem i = new InventoryItem();
        i.setId(id);
        i.setIsUsed(isUsed);
        return i;
    }

    public static InventoryItem newPhone(Long phoneId) {
        InventoryItem i = new InventoryItem();
        i.setId(phoneId);
        i.setPhoneId(phoneId);
        return i;
    }
}
